@@ -1,7 +1,6 @@
 import os
 import boto3
 import base64
-import inspect
 import tarfile
 import logging
 import daggerml as dml
@@ -98,8 +97,7 @@ def exec_fn(f):
 
 @exec_fn
 def tar(path):
-    base = inspect.stack()[2][0].f_code.co_filename
-    path = os.path.abspath(os.path.join(base, path))
+    path = os.path.abspath(path)
     logger.info('set path to: %r', path)
     with NamedTemporaryFile('w+') as f:
         with tarfile.open(f.name, "w:gz") as tar:
@@ -119,8 +117,7 @@ dml.Dag.s3_tar = tar
 
 @exec_fn
 def upload(path):
-    base = inspect.stack()[2][0].f_code.co_filename
-    path = os.path.abspath(os.path.join(base, path))
+    path = os.path.abspath(path)
     logger.info('set path to: %r', path)
     md5_hash = md5sum(path)
     key = f'executor/s3/data/misc/{md5_hash}/' + path.split('/')[-1]
@@ -138,7 +135,7 @@ def parquet(df):
     if not isinstance(df, pd.DataFrame):
         raise TypeError('df must be a dataframe')
     _hash = pu.hash_pandas_object(df).sum()
-    key = f'executor/s3/data/dataframe-pandas/{_hash}'
+    key = f'executor/s3/data/dataframe-pandas/{_hash}.parquet'
     s3_loc = f's3://{BUCKET}/{key}'
     df.to_parquet(s3_loc)
     return s3_loc
@@ -146,4 +143,4 @@ def parquet(df):
 
 @exec_fn
 def new_prefix():
-    return f's3://{BUCKET}/executor/s3/data/unique-prefix/{uuid4().hex}'
+    return f's3://{BUCKET}/executor/s3/data/unique-prefix/{uuid4().hex}/'
