@@ -6,7 +6,7 @@ from daggerml import Resource
 TAG = 'com.daggerml.resource.s3'
 DAG_NAME = TAG
 DAG_VERSION = 1
-CONFIG_FILE = os.path.expanduser(os.getenv('DML_S3_CONFIG', '~/.config/dml-s3.json'))
+CONFIG_FILE = os.path.expanduser(os.getenv('DML_S3_CONFIG', '~/.dml/s3.json'))
 
 if os.path.isfile(CONFIG_FILE):
     with open(CONFIG_FILE, 'r') as f:
